%global srcname setuptools
%global python_wheel_name %{srcname}-%{version}-py3-none-any.whl

%bcond_with bootstrap

%if %{with bootstrap}
%bcond_with tests
%else
%bcond_without tests
%endif

Summary:        Easily download, build, install, upgrade, and uninstall Python packages
Name:           python-setuptools
Version:        68.0.0
Release:        2%{?dist}
License:        MIT and (BSD or ASL 2.0)
URL:            https://github.com/pypa/setuptools
Source0:        %{pypi_source %{srcname} %{version}}

Patch0001:      backport-CVE-2024-6345.patch
Patch3001:      Remove-optional-or-unpackaged-test-deps.patch
Patch3002:      Adjust-the-setup.py-install-deprecation-message.patch

BuildRequires:  python%{python3_pkgversion}-devel

%if %{with tests}
BuildRequires:  gcc
%endif

%if %{without bootstrap}
BuildRequires:  pyproject-rpm-macros python%{python3_pkgversion}-setuptools python3-rpm-generators
%endif

BuildArch:      noarch

%description
Setuptools is a fully-featured, actively-maintained, and stable library
designed to facilitate packaging Python projects.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.

# these bundles are generated by following command:
# cat pkg_resources/_vendor/vendored.txt setuptools/_vendor/vendored.txt > allvendor.txt
# %%{_rpmconfigdir}/pythonbundles.py allvendor.txt --namespace 'python3dist'
%global bundled %{expand:
Provides: bundled(python%{python3_pkgversion}dist(platformdirs)) = 2.6.2
Provides: bundled(python%{python3_pkgversion}dist(importlib-metadata)) = 6
Provides: bundled(python%{python3_pkgversion}dist(importlib-resources)) = 5.10.2
Provides: bundled(python%{python3_pkgversion}dist(jaraco-text)) = 3.7
Provides: bundled(python%{python3_pkgversion}dist(more-itertools)) = 8.8
Provides: bundled(python%{python3_pkgversion}dist(ordered-set)) = 3.1.1
Provides: bundled(python%{python3_pkgversion}dist(packaging)) = 23.1
Provides: bundled(python%{python3_pkgversion}dist(typing-extensions)) = 4.4
Provides: bundled(python%{python3_pkgversion}dist(typing-extensions)) = 4.0.1
Provides: bundled(python%{python3_pkgversion}dist(zipp)) = 3.7
Provides: bundled(python%{python3_pkgversion}dist(tomli)) = 2.0.1
}

%package -n python%{python3_pkgversion}-setuptools
Summary:        Easily build and distribute Python 3 packages
%{bundled}

%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(setuptools) = %{version}
Provides:       python%{python3_version}dist(setuptools) = %{version}
%endif

%description -n python%{python3_pkgversion}-setuptools
Setuptools is a collection of enhancements to the Python 3 distutils that allow
you to more easily build and distribute Python 3 packages, especially ones that
have dependencies on other packages.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.

%if %{without bootstrap}
%package -n     %{python_wheel_pkg_prefix}-%{srcname}-wheel
Summary:        The setuptools wheel
%{bundled}

%description -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
A Python wheel of setuptools to use with venv.
%endif


%prep
%autosetup -p1 -n %{srcname}-%{version}

find setuptools pkg_resources -name \*.py | xargs sed -i -e '1 {/^#!\//d}'
rm -f setuptools/*.exe
rm -r docs/conf.py

%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x testing}
%endif

%build
%if %{with bootstrap}
%py3_build
%else
%pyproject_wheel
%endif


%install
%if %{with bootstrap}
%py3_install
%else
%pyproject_install
%pyproject_save_files setuptools pkg_resources _distutils_hack
%endif

rm -rf %{buildroot}%{python3_sitelib}/pkg_resources/tests/
%if %{without bootstrap}
sed -i '/\/pkg_resources\/tests\b/d' %{pyproject_files}

mkdir -p %{buildroot}%{python_wheel_dir}
install -p %{_pyproject_wheeldir}/%{python_wheel_name} -t %{buildroot}%{python_wheel_dir}
%endif

%check
%{_rpmconfigdir}/pythonbundles.py */_vendor/vendored.txt --namespace 'python%{python3_pkgversion}dist' --compare-with '%{bundled}'

test ! -d %{buildroot}%{python3_sitelib}/pkg_resources/tests
test ! -d %{buildroot}%{python3_sitelib}/setuptools/tests

%if %{without bootstrap}
# Regression test to keep wheel not be larger than 900 kB
test $(stat --format %%s %{_pyproject_wheeldir}/%{python_wheel_name}) -lt 900000
%endif

%if %{with tests}
rm pyproject.toml

PRE_BUILT_SETUPTOOLS_WHEEL=%{_pyproject_wheeldir}/%{python_wheel_name} \
PYTHONPATH=$(pwd) %pytest \
 --ignore=setuptools/tests/test_integration.py \
 --ignore=setuptools/tests/integration/ \
 --ignore=setuptools/tests/test_editable_install.py \
 --ignore=setuptools/tests/config/test_apply_pyprojecttoml.py \
 --ignore=tools/finalize.py \
 -k "not test_pip_upgrade_from_source and \
     not test_setup_requires_honors_fetch_params and \
     not test_build_with_pyproject_configi and \
     not test_project and \
     not test_setupcfg_metadata and \
     not test_build_with_pyproject_config and \
     not test_build_with_discovered_name and \
     not test_include_package_data"
%endif

%files -n python%{python3_pkgversion}-setuptools %{?!with_bootstrap:-f %{pyproject_files}}
%license LICENSE
%doc docs/* CHANGES.rst README.rst
%{python3_sitelib}/distutils-precedence.pth
%if %{with bootstrap}
%{python3_sitelib}/setuptools-%{version}-py%{python3_version}.egg-info/
%{python3_sitelib}/pkg_resources/
%{python3_sitelib}/setuptools/
%{python3_sitelib}/_distutils_hack/
%endif

%if %{without bootstrap}
%files -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
%license LICENSE
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{python_wheel_name}
%endif

%changelog
* Thu Jul 18 2024 Shuo Wang <abushwang@tencent.com> - 68.0.0-2
- fix CVE-2024-6345
- Modernize package_index VCS handling

* Wed Jan 10 2024 Upgrade Robot <upbot@opencloudos.org> - 68.0.0-1
- Upgrade to version 68.0.0

* Tue Sep 19 2023 Shuo Wang <abushwang@tencent.com> - 65.5.1-2
- Rebuilt for python 3.11

* Tue Sep 19 2023 Shuo Wang <abushwang@tencent.com> - 65.5.1-1
- update to 65.5.1

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 62.3.2-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 62.3.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 62.3.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 62.3.2-2
- Rebuilt for OpenCloudOS Stream 23

* Thu May 26 2022 Zhao Zhen <jeremiazhao@tencent.com> - 62.3.2-1
- Initial building.
